# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import subscription_pb2 as eolymp_dot_commerce_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/commerce/events.proto\x12\x0f\x65olymp.commerce\x1a\"eolymp/commerce/subscription.proto\"w\n\x18SubscriptionChangedEvent\x12-\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1d.eolymp.commerce.Subscription\x12,\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1d.eolymp.commerce.SubscriptionB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _SUBSCRIPTIONCHANGEDEVENT._serialized_start=85
  _SUBSCRIPTIONCHANGEDEVENT._serialized_end=204
# @@protoc_insertion_point(module_scope)
