# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/customer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.commerce import customer_pb2 as eolymp_dot_commerce_dot_customer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/commerce/customer_service.proto\x12\x0f\x65olymp.commerce\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/commerce/customer.proto\"B\n\x13\x43reateCustomerInput\x12+\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x19.eolymp.commerce.Customer\"+\n\x14\x43reateCustomerOutput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"W\n\x13UpdateCustomerInput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12+\n\x08\x63ustomer\x18\x02 \x01(\x0b\x32\x19.eolymp.commerce.Customer\"\x16\n\x14UpdateCustomerOutput\"\x14\n\x12ListCustomersInput\"N\n\x13ListCustomersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.commerce.Customer\",\n\x15\x44\x65scribeCustomerInput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeCustomerOutput\x12+\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x19.eolymp.commerce.Customer\"*\n\x13\x44\x65leteCustomerInput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteCustomerOutput2\xc4\x04\n\x0f\x43ustomerService\x12n\n\x0e\x43reateCustomer\x12$.eolymp.commerce.CreateCustomerInput\x1a%.eolymp.commerce.CreateCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12n\n\x0eUpdateCustomer\x12$.eolymp.commerce.UpdateCustomerInput\x1a%.eolymp.commerce.UpdateCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12t\n\x10\x44\x65scribeCustomer\x12&.eolymp.commerce.DescribeCustomerInput\x1a\'.eolymp.commerce.DescribeCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12k\n\rListCustomers\x12#.eolymp.commerce.ListCustomersInput\x1a$.eolymp.commerce.ListCustomersOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12n\n\x0e\x44\x65leteCustomer\x12$.eolymp.commerce.DeleteCustomerInput\x1a%.eolymp.commerce.DeleteCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2B3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.customer_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _CUSTOMERSERVICE.methods_by_name['CreateCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['CreateCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['UpdateCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['UpdateCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['DescribeCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['DescribeCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['ListCustomers']._options = None
  _CUSTOMERSERVICE.methods_by_name['ListCustomers']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['DeleteCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['DeleteCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CREATECUSTOMERINPUT._serialized_start=127
  _CREATECUSTOMERINPUT._serialized_end=193
  _CREATECUSTOMEROUTPUT._serialized_start=195
  _CREATECUSTOMEROUTPUT._serialized_end=238
  _UPDATECUSTOMERINPUT._serialized_start=240
  _UPDATECUSTOMERINPUT._serialized_end=327
  _UPDATECUSTOMEROUTPUT._serialized_start=329
  _UPDATECUSTOMEROUTPUT._serialized_end=351
  _LISTCUSTOMERSINPUT._serialized_start=353
  _LISTCUSTOMERSINPUT._serialized_end=373
  _LISTCUSTOMERSOUTPUT._serialized_start=375
  _LISTCUSTOMERSOUTPUT._serialized_end=453
  _DESCRIBECUSTOMERINPUT._serialized_start=455
  _DESCRIBECUSTOMERINPUT._serialized_end=499
  _DESCRIBECUSTOMEROUTPUT._serialized_start=501
  _DESCRIBECUSTOMEROUTPUT._serialized_end=570
  _DELETECUSTOMERINPUT._serialized_start=572
  _DELETECUSTOMERINPUT._serialized_end=614
  _DELETECUSTOMEROUTPUT._serialized_start=616
  _DELETECUSTOMEROUTPUT._serialized_end=638
  _CUSTOMERSERVICE._serialized_start=641
  _CUSTOMERSERVICE._serialized_end=1221
# @@protoc_insertion_point(module_scope)
