# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/discussion_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import discussion_pb2 as eolymp_dot_discussion_dot_discussion__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/discussion/discussion_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/discussion/discussion.proto\x1a!eolymp/wellknown/expression.proto\"@\n\x17\x44\x65scribeDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"M\n\x18\x44\x65scribeDiscussionOutput\x12\x31\n\ndiscussion\x18\x01 \x01(\x0b\x32\x1d.eolymp.discussion.Discussion\"\xca\x01\n\x14ListDiscussionsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12?\n\x07\x66ilters\x18( \x01(\x0b\x32..eolymp.discussion.ListDiscussionsInput.Filter\x1a\x43\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"T\n\x15ListDiscussionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.discussion.Discussion\"J\n\x15\x43reateDiscussionInput\x12\x31\n\ndiscussion\x18\x01 \x01(\x0b\x32\x1d.eolymp.discussion.Discussion\"/\n\x16\x43reateDiscussionOutput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\"a\n\x15UpdateDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\x31\n\ndiscussion\x18\x02 \x01(\x0b\x32\x1d.eolymp.discussion.Discussion\"\x18\n\x16UpdateDiscussionOutput\".\n\x15\x44\x65leteDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteDiscussionOutput\":\n\x13VoteDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"*\n\x14VoteDiscussionOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\x32\x80\t\n\x11\x44iscussionService\x12\xc5\x01\n\x12\x44\x65scribeDiscussion\x12*.eolymp.discussion.DescribeDiscussionInput\x1a+.eolymp.discussion.DescribeDiscussionOutput\"V\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:discussion:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1e\x12\x1c/discussions/{discussion_id}\x12\xab\x01\n\x0fListDiscussions\x12\'.eolymp.discussion.ListDiscussionsInput\x1a(.eolymp.discussion.ListDiscussionsOutput\"E\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:discussion:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/discussions\x12\xaf\x01\n\x10\x43reateDiscussion\x12(.eolymp.discussion.CreateDiscussionInput\x1a).eolymp.discussion.CreateDiscussionOutput\"F\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/discussions\x12\xbf\x01\n\x10UpdateDiscussion\x12(.eolymp.discussion.UpdateDiscussionInput\x1a).eolymp.discussion.UpdateDiscussionOutput\"V\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/discussions/{discussion_id}\x12\xbf\x01\n\x10\x44\x65leteDiscussion\x12(.eolymp.discussion.DeleteDiscussionInput\x1a).eolymp.discussion.DeleteDiscussionOutput\"V\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/discussions/{discussion_id}\x12\xbe\x01\n\x0eVoteDiscussion\x12&.eolymp.discussion.VoteDiscussionInput\x1a\'.eolymp.discussion.VoteDiscussionOutput\"[\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\"!/discussions/{discussion_id}/voteB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.discussion_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _DISCUSSIONSERVICE.methods_by_name['DescribeDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['DescribeDiscussion']._serialized_options = b'\202\343\n\036\212\343\n\032discussion:discussion:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\036\022\034/discussions/{discussion_id}'
  _DISCUSSIONSERVICE.methods_by_name['ListDiscussions']._options = None
  _DISCUSSIONSERVICE.methods_by_name['ListDiscussions']._serialized_options = b'\202\343\n\036\212\343\n\032discussion:discussion:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/discussions'
  _DISCUSSIONSERVICE.methods_by_name['CreateDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['CreateDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\"\014/discussions'
  _DISCUSSIONSERVICE.methods_by_name['UpdateDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['UpdateDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/discussions/{discussion_id}'
  _DISCUSSIONSERVICE.methods_by_name['DeleteDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['DeleteDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/discussions/{discussion_id}'
  _DISCUSSIONSERVICE.methods_by_name['VoteDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['VoteDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002#\"!/discussions/{discussion_id}/vote'
  _DESCRIBEDISCUSSIONINPUT._serialized_start=235
  _DESCRIBEDISCUSSIONINPUT._serialized_end=299
  _DESCRIBEDISCUSSIONOUTPUT._serialized_start=301
  _DESCRIBEDISCUSSIONOUTPUT._serialized_end=378
  _LISTDISCUSSIONSINPUT._serialized_start=381
  _LISTDISCUSSIONSINPUT._serialized_end=583
  _LISTDISCUSSIONSINPUT_FILTER._serialized_start=516
  _LISTDISCUSSIONSINPUT_FILTER._serialized_end=583
  _LISTDISCUSSIONSOUTPUT._serialized_start=585
  _LISTDISCUSSIONSOUTPUT._serialized_end=669
  _CREATEDISCUSSIONINPUT._serialized_start=671
  _CREATEDISCUSSIONINPUT._serialized_end=745
  _CREATEDISCUSSIONOUTPUT._serialized_start=747
  _CREATEDISCUSSIONOUTPUT._serialized_end=794
  _UPDATEDISCUSSIONINPUT._serialized_start=796
  _UPDATEDISCUSSIONINPUT._serialized_end=893
  _UPDATEDISCUSSIONOUTPUT._serialized_start=895
  _UPDATEDISCUSSIONOUTPUT._serialized_end=919
  _DELETEDISCUSSIONINPUT._serialized_start=921
  _DELETEDISCUSSIONINPUT._serialized_end=967
  _DELETEDISCUSSIONOUTPUT._serialized_start=969
  _DELETEDISCUSSIONOUTPUT._serialized_end=993
  _VOTEDISCUSSIONINPUT._serialized_start=995
  _VOTEDISCUSSIONINPUT._serialized_end=1053
  _VOTEDISCUSSIONOUTPUT._serialized_start=1055
  _VOTEDISCUSSIONOUTPUT._serialized_end=1097
  _DISCUSSIONSERVICE._serialized_start=1100
  _DISCUSSIONSERVICE._serialized_end=2252
# @@protoc_insertion_point(module_scope)
